==> lowcode-editor-skeleton-2.0.5.tgz: package/es/components/settings/components/form-row/index.js <==
import _Row from "antd/es/row";
import _Col from "antd/es/col";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/extends";
var _excluded = ["children", "className", "style"];
import React from 'react';
import { observer, RecursionField, useField, useFieldSchema } from '@formily/react';
import cls from 'classnames';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
var useCols = function useCols() {
  var colsField = useField();
  var schema = useFieldSchema();
  var cols = [];
  schema.mapProperties(function (schema, name) {
    var _schema$xComponent;
    var field = colsField.query(colsField.address.concat(name)).take();
    if ((field === null || field === void 0 ? void 0 : field.display) === 'none' || (field === null || field === void 0 ? void 0 : field.display) === 'hidden') return;
    if (((_schema$xComponent = schema['x-component']) === null || _schema$xComponent === void 0 ? void 0 : _schema$xComponent.indexOf('Col')) > -1) {
      var _schema$xComponentP;
      cols.push({
        name: name,
        props: _extends({
          key: (schema === null || schema === void 0 ? void 0 : (_schema$xComponentP = schema['x-component-props']) === null || _schema$xComponentP === void 0 ? void 0 : _schema$xComponentP.key) || name
        }, schema === null || schema === void 0 ? void 0 : schema['x-component-props']),
        schema: schema
      });
    }
  });
  return cols;
};
export var FormRow = observer(function (_ref) {
  var children = _ref.children,
    className = _ref.className,
    style = _ref.style,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var prefixCls = usePrefixCls('formily-row', props);
  var cols = useCols();
  return /*#__PURE__*/React.createElement(_Row, _extends({}, props, {
    className: cls(prefixCls, className)
  }), cols.map(function (_ref2, index) {
    var props = _ref2.props,
      schema = _ref2.schema,
      name = _ref2.name;
    return /*#__PURE__*/React.createElement(_Col, _extends({
      key: index
    }, props), /*#__PURE__*/React.createElement(RecursionField, {
      schema: schema,
      name: name
    }));
  }));
}, {
  forwardRef: true
});
var FormCol = function FormCol(_ref3) {
  var children = _ref3.children;
  return /*#__PURE__*/React.createElement(React.Fragment, null, children);
};
FormRow.Col = FormCol;
export default FormRow;

==> lowcode-editor-skeleton-2.0.7.tgz: package/es/components/settings/components/form-row/index.js <==
import _Row from "antd/es/row";
import _Col from "antd/es/col";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/extends";
var _excluded = ["children", "className", "style"];
import React from 'react';
import { observer, RecursionField, useField, useFieldSchema } from '@formily/react';
import cls from 'classnames';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
var useCols = function useCols() {
  var colsField = useField();
  var schema = useFieldSchema();
  var cols = [];
  schema.mapProperties(function (schema, name) {
    var _schema$xComponent;
    var field = colsField.query(colsField.address.concat(name)).take();
    if ((field === null || field === void 0 ? void 0 : field.display) === 'none' || (field === null || field === void 0 ? void 0 : field.display) === 'hidden') return;
    if (((_schema$xComponent = schema['x-component']) === null || _schema$xComponent === void 0 ? void 0 : _schema$xComponent.indexOf('Col')) > -1) {
      cols.push({
        name: name,
        props: _extends({}, schema === null || schema === void 0 ? void 0 : schema['x-component-props']),
        schema: schema
      });
    }
  });
  return cols;
};
export var FormRow = observer(function (_ref, ref) {
  var children = _ref.children,
    className = _ref.className,
    style = _ref.style,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  var prefixCls = usePrefixCls('formily-row', props);
  var cols = useCols();
  return /*#__PURE__*/React.createElement(_Row, _extends({
    ref: ref
  }, props, {
    className: cls(prefixCls, className)
  }), cols.map(function (_ref2, index) {
    var props = _ref2.props,
      schema = _ref2.schema,
      name = _ref2.name;
    return /*#__PURE__*/React.createElement(_Col, _extends({
      key: index
    }, props), /*#__PURE__*/React.createElement(RecursionField, {
      schema: schema,
      name: name
    }));
  }));
}, {
  forwardRef: true
});
var FormCol = function FormCol(_ref3) {
  var children = _ref3.children;
  return /*#__PURE__*/React.createElement(React.Fragment, null, children);
};
FormRow.Col = FormCol;
export default FormRow;
